@@ -259,18 +259,18 @@ impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M55<T> {
     /// Cofactor = (-1)^(i+j) M(i, j).det()
     ///
     fn inverse(&self) -> Option<Self> {
-
+        let one = T::one();
         let det = self.det();
         if det.abs() > T::epsilon() {
             let mut cofactors: M55<T> = M55::zeros();
-
             for i in 0..self.rows() {
                 for j in 0..self.cols() {
-                    let sign = (-T::one()).powi((i + j) as i32);
-                    cofactors[(i, j)] = sign * self.get_submatrix((i, j)).det();
+                    let sign = if (i + j) % 2 == 0 {one} else {-one};
+                    // transpose in place
+                    cofactors[(j, i)] = sign * self.get_submatrix((i, j)).det();
                 }
             }
-            Some(cofactors.transpose() * (T::one() / det))
+            Some(cofactors * (T::one() / det))
         } else {
             None
         }
@@ -291,7 +291,6 @@ impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M55<T> {
                 normalize(&mut *q_tilde);
                 q[i] = q_tilde;
             }
-            // TODO(elsuizo:2020-08-05): do this with a another for loop
             let basis = V5::new([q[0], q[1], q[2], q[3], q[4]]);
             let q     = M55::new_from_vecs(basis);
             let r     = q.transpose() * (*self);
@@ -702,10 +701,8 @@ impl<T: Num + Copy> M55<T> {
     /// transform the matrix to a flatten vector
     pub fn as_vec(&self) -> [T; 25] {
         let mut result = [T::zero(); 25];
-        for i in 0..self.rows() {
-            for j in 0..self.cols() {
-                result[i] = self[(i, j)];
-            }
+        for (index, element) in self.iter().flatten().enumerate() {
+            result[index] = *element;
         }
         result
     }
@@ -737,7 +734,6 @@ impl<T: Num + Copy> M55<T> {
         }
         result
     }
-    // TODO(elsuizo:2020-06-02): this could be optimize
 
     /// get the a submatrix from discard row `i` and column `j`
     fn get_submatrix(&self, selected: (usize, usize)) -> M44<T> {
@@ -747,17 +743,16 @@ impl<T: Num + Copy> M55<T> {
         for i in 0..self.rows() {
             for j in 0..self.cols() {
                 if !(i == selected.0 || j == selected.1) {
-                    // get the values from the M44
                     values[index] = self[(i, j)];
                     index += 1;
                 }
             }
         }
-        let mut i: usize = 0;
+        index = 0;
         for r in 0..result.rows() {
             for c in 0..result.cols() {
-                result[(r, c)] = values[i];
-                i += 1;
+                result[(r, c)] = values[index];
+                index += 1;
             }
         }
         return result;
@@ -1263,4 +1258,5 @@ mod test_matrix5x5 {
             &expected[..]
         );
     }
+
 }
