@@ -45,6 +45,27 @@ use crate::traits::LinearAlgebra;
 #[derive(Copy, Clone, Debug, PartialEq)]
 pub struct M66<T>([[T; 6]; 6]);
 
+//-------------------------------------------------------------------------
+//                        macros
+//-------------------------------------------------------------------------
+#[macro_export]
+macro_rules! m66_new {
+    ($($first_row:expr),*;
+     $($second_row:expr),*;
+     $($third_row:expr),*;
+     $($fourth_row:expr),*;
+     $($fifth_row:expr),*;
+     $($sixth_row:expr),*
+     ) => {
+        M66::new([[$($first_row),*],
+                 [$($second_row),*],
+                 [$($third_row),*],
+                 [$($fourth_row),*],
+                 [$($fifth_row),*],
+                 [$($sixth_row),*]])
+    }
+}
+
 impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M66<T> {
     #[inline]
     fn rows(&self) -> usize {
@@ -894,16 +915,18 @@ impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M66<T> {
     ///
     /// Cofactor = (-1)^(i+j) * M(i, j).det()
     fn inverse(&self) -> Option<Self> {
+        let one = T::one();
         let det = self.det();
         if det.abs() > T::epsilon() {
             let mut cofactors: M66<T> = M66::zeros();
-            for i in 0..self.rows() {
-                for j in 0..self.cols() {
-                    let sign = (-T::one()).powi((i + j) as i32);
-                    cofactors[(i, j)] = sign * self.get_submatrix((i, j)).det();
+            for i in 0..6 {
+                for j in 0..6 {
+                    let sign = if (i + j) % 2 == 0 {one} else {-one};
+                    // transpose in place
+                    cofactors[(j, i)] = sign * self.get_submatrix((i, j)).det();
                 }
             }
-            Some(cofactors.transpose() * (T::one() / det))
+            Some(cofactors * (one / det))
         } else {
             None
         }
@@ -1427,10 +1450,8 @@ impl<T: Num + Copy + std::iter::Sum> M66<T> {
     /// transform the matrix to a flatten vector
     pub fn as_vec(&self) -> [T; 36] {
         let mut result = [T::zero(); 36];
-        for i in 0..self.rows() {
-            for j in 0..self.cols() {
-                result[i] = self[(i, j)];
-            }
+        for (index, element) in self.iter().flatten().enumerate() {
+            result[index] = *element;
         }
         result
     }
@@ -1464,28 +1485,25 @@ impl<T: Num + Copy + std::iter::Sum> M66<T> {
         result
     }
 
-    // TODO(elsuizo:2020-06-02): this could be optimize
-
     /// get the a submatrix from discard row `i` and column `j`
     ///
     fn get_submatrix(&self, selected: (usize, usize)) -> M55<T> {
         let mut values: [T; 25] = [T::zero(); 25];
         let mut result: M55<T> = M55::zeros();
         let mut index: usize = 0;
-        for i in 0..self.rows() {
-            for j in 0..self.cols() {
+        for i in 0..6 {
+            for j in 0..6 {
                 if !(i == selected.0 || j == selected.1) {
-                    // get the values from the Matrix4x4
                     values[index] = self[(i, j)];
                     index += 1;
                 }
             }
         }
-        let mut i: usize = 0;
-        for r in 0..result.rows() {
-            for c in 0..result.cols() {
-                result[(r, c)] = values[i];
-                i += 1;
+        index = 0;
+        for r in 0.. 5 {
+            for c in 0..5 {
+                result[(r, c)] = values[index];
+                index += 1;
             }
         }
         return result;
@@ -1689,26 +1707,6 @@ impl<T: Num + fmt::Display> fmt::Display for M66<T> {
     }
 }
 
-//-------------------------------------------------------------------------
-//                        macros
-//-------------------------------------------------------------------------
-#[macro_export]
-macro_rules! m66_new {
-    ($($first_row:expr),*;
-     $($second_row:expr),*;
-     $($third_row:expr),*;
-     $($fourth_row:expr),*;
-     $($fifth_row:expr),*;
-     $($sixth_row:expr),*
-     ) => {
-        M66::new([[$($first_row),*],
-                 [$($second_row),*],
-                 [$($third_row),*],
-                 [$($fourth_row),*],
-                 [$($fifth_row),*],
-                 [$($sixth_row),*]])
-    }
-}
 
 //-------------------------------------------------------------------------
 //                        tests
@@ -1723,7 +1721,7 @@ mod test_matrix6x6 {
     use crate::vector6::V6;
 
     // TODO(elsuizo:2020-06-02): ver porque tenemos que bajar el EPS para que ande inverse()
-    const EPS: f32 = 1e-5;
+    const EPS: f32 = 1e-4;
 
     #[test]
     fn sub_test() {
